package pathgame.rendering;

import me.hammerle.snuviengine.api.Renderer;
import pathgame.gameplay.Level;
import pathgame.gameplay.Player;

public class ScoreMenuRenderer {
    public void renderTick(Renderer r, float lag, Level level) {
        float windowWidth = r.getViewWidth();
        float windowHeight = r.getViewHeight();
        float paddingX = 30;
        float paddingY = 50;
        r.setMixColorEnabled(false);
        r.setColorEnabled(true);
        r.setTextureEnabled(false);
        r.enableBlending();
        r.getColorRenderer().drawRectangle(paddingX, paddingY, windowWidth - paddingX, windowHeight - paddingY, 0x90000000);

        r.setTextureEnabled(true);
        r.translateTo(0.0f, 0.0f);
        float scale = scale(r, 1);

        Player p = level.getPlayer();
        String message = String.format("#00AA00%d#FFFFFF of #00AA00%d#FFFFFF Energy used",
                p.getEnergyUsed(), p.getEnergySupply());

        r.getFontRenderer().drawString((windowWidth * scale - getWidth(r, message)) / 2, (windowHeight * scale - getHeight(r, message)) / 2 - windowHeight * scale * 0.5f * 0.15f, message);

        message = getMessage(p.getEnergyUsed(), level.getAlgorithmValue(), p.getEnergySupply());

        r.getFontRenderer().drawString((windowWidth * scale - getWidth(r, message)) / 2, (windowHeight * scale - getHeight(r, message)) / 2 - windowHeight * scale * 0.5f * (-0.15f), message);

        scale = scale(r, 2);
        if(p.hasLost()) {
            message = "What a pity! Out of energy!";
        } else {
            message = "Congratulations!";
        }
        r.getFontRenderer().drawString((windowWidth * scale - getWidth(r, message)) / 2, (windowHeight * scale - getHeight(r, message)) / 2, message);

        message = "[#AAAAAAPRESS ENTER#FFFFFF]";
        r.getFontRenderer().drawString((windowWidth * scale - getWidth(r, message)) / 2, (windowHeight * scale - paddingY * scale - getHeight(r, message)) - 10, message);
    }

    private float getWidth(Renderer r, String s) {
        return r.getFontRenderer().getSize(s).getStringWidth();
    }

    private float getHeight(Renderer r, String s) {
        return r.getFontRenderer().getSize(s).getStringHeight();
    }

    private float scale(Renderer r, int scale) {
        r.scale(scale, scale);
        r.updateMatrix();
        return 1.0f / scale;
    }

    private String getMessage(int playerEnergy, int algorithmEnergy, int maxEnergy) {
        if(playerEnergy == algorithmEnergy) {
            return "As good as the algorithm!";
        }
        float energyPercent = ((float) playerEnergy / maxEnergy) * Level.ALGORITHM_4;
        if(energyPercent < Level.ALGORITHM_1) {
            return "Better than the algorithm!";
        } else if(energyPercent < Level.ALGORITHM_2) {
            return "0-10% over the algorithm!";
        } else if(energyPercent < Level.ALGORITHM_3) {
            return "10-20% over the algorithm!";
        } else if(energyPercent < Level.ALGORITHM_4) {
            return "20-30% over the algorithm!";
        } else {
            return "30% over the algorithm!";
        }
    }
}
